@@ -681,11 +681,19 @@ activate_action_extract (GtkAction *action,
 }
 
 
+void
+activate_action_extract_folder_from_sidebar (GtkAction *action,
+			 		     gpointer   data)
+{
+	dlg_extract_folder_from_sidebar (NULL, data);
+}
+
+
 void
 activate_action_copy (GtkAction *action,
 		      gpointer   data)
 {
-	fr_window_copy_selection ((FrWindow*) data);
+	fr_window_copy_selection ((FrWindow*) data, FALSE);
 }
 
 
@@ -693,7 +701,7 @@ void
 activate_action_cut (GtkAction *action,
 		     gpointer   data)
 {
-	fr_window_cut_selection ((FrWindow*) data);
+	fr_window_cut_selection ((FrWindow*) data, FALSE);
 }
 
 
@@ -701,7 +709,7 @@ void
 activate_action_paste (GtkAction *action,
 		       gpointer   data)
 {
-	fr_window_paste_selection ((FrWindow*) data);
+	fr_window_paste_selection ((FrWindow*) data, FALSE);
 }
 
 
@@ -709,7 +717,7 @@ void
 activate_action_rename (GtkAction *action,
 			gpointer   data)
 {
-	fr_window_rename_selection ((FrWindow*) data);
+	fr_window_rename_selection ((FrWindow*) data, FALSE);
 }
 
 
@@ -721,6 +729,46 @@ activate_action_delete (GtkAction *action,
 }
 
 
+void
+activate_action_copy_folder_from_sidebar (GtkAction *action,
+		      			  gpointer   data)
+{
+	fr_window_copy_selection ((FrWindow*) data, TRUE);
+}
+
+
+void
+activate_action_cut_folder_from_sidebar (GtkAction *action,
+		     			 gpointer   data)
+{
+	fr_window_cut_selection ((FrWindow*) data, TRUE);
+}
+
+
+void
+activate_action_paste_folder_from_sidebar (GtkAction *action,
+		       			   gpointer   data)
+{
+	fr_window_paste_selection ((FrWindow*) data, TRUE);
+}
+
+
+void
+activate_action_rename_folder_from_sidebar (GtkAction *action,
+					    gpointer   data)
+{
+	fr_window_rename_selection ((FrWindow*) data, TRUE);
+}
+
+
+void
+activate_action_delete_folder_from_sidebar (GtkAction *action,
+					    gpointer   data)
+{
+	dlg_delete_from_sidebar (NULL, data);
+}
+
+
 void
 activate_action_select_all (GtkAction *action,
 			    gpointer   data)
@@ -759,7 +807,7 @@ activate_action_view_or_open (GtkAction *action,
 	file_list = fr_window_get_file_list_selection (window, FALSE, NULL);
 	if (file_list == NULL)
 		return;
-	fr_window_view_or_open_file (window, (char*) file_list->data);
+	fr_window_open_files (window, file_list, FALSE);
 	path_list_free (file_list);
 }
 
@@ -769,7 +817,16 @@ activate_action_open_folder (GtkAction *action,
 			     gpointer   data)
 {
 	FrWindow *window = data;
-	fr_window_current_folder_activated (window);
+	fr_window_current_folder_activated (window, FALSE);
+}
+
+
+void
+activate_action_open_folder_from_sidebar (GtkAction *action,
+			                  gpointer   data)
+{
+	FrWindow *window = data;
+	fr_window_current_folder_activated (window, TRUE);
 }
 
 
