@@ -33,13 +33,13 @@
 
 
 /* -- filter -- */
- 
- 
+
+
 typedef enum {
-        GNOME_VFS_DIRECTORY_FILTER_DEFAULT = 0,
-        GNOME_VFS_DIRECTORY_FILTER_NODOTFILES = 1 << 1,
-        GNOME_VFS_DIRECTORY_FILTER_IGNORECASE = 1 << 2,
-        GNOME_VFS_DIRECTORY_FILTER_NOBACKUPFILES = 1 << 3
+	GNOME_VFS_DIRECTORY_FILTER_DEFAULT = 0,
+	GNOME_VFS_DIRECTORY_FILTER_NODOTFILES = 1 << 1,
+	GNOME_VFS_DIRECTORY_FILTER_IGNORECASE = 1 << 2,
+	GNOME_VFS_DIRECTORY_FILTER_NOBACKUPFILES = 1 << 3
 } GnomeVFSDirectoryFilterOptions;
 
 typedef struct {
@@ -50,22 +50,22 @@ typedef struct {
 } Filter;
 
 
-static Filter * 
-filter_new (const gchar                    *pattern, 
+static Filter *
+filter_new (const gchar                    *pattern,
 	    GnomeVFSDirectoryFilterOptions  options)
 {
 	Filter *filter;
 
-        filter = g_new (Filter, 1);
+	filter = g_new (Filter, 1);
 
 	filter->pattern = g_strdup (pattern);
-        filter->patterns = search_util_get_patterns (pattern);
-        filter->fnmatch_flags = 0;
+	filter->patterns = search_util_get_patterns (pattern);
+	filter->fnmatch_flags = 0;
 	filter->options = options;
-        if ((options & GNOME_VFS_DIRECTORY_FILTER_IGNORECASE) == GNOME_VFS_DIRECTORY_FILTER_IGNORECASE)
-                filter->fnmatch_flags |= FNM_CASEFOLD;
+	if ((options & GNOME_VFS_DIRECTORY_FILTER_IGNORECASE) == GNOME_VFS_DIRECTORY_FILTER_IGNORECASE)
+		filter->fnmatch_flags |= FNM_CASEFOLD;
 
-        return filter;
+	return filter;
 }
 
 
@@ -74,20 +74,20 @@ filter_set_options (Filter                         *filter,
 		    GnomeVFSDirectoryFilterOptions  options)
 {
 	filter->options = options;
-        if ((options & GNOME_VFS_DIRECTORY_FILTER_IGNORECASE) == GNOME_VFS_DIRECTORY_FILTER_IGNORECASE)
-                filter->fnmatch_flags |= FNM_CASEFOLD;
+	if ((options & GNOME_VFS_DIRECTORY_FILTER_IGNORECASE) == GNOME_VFS_DIRECTORY_FILTER_IGNORECASE)
+		filter->fnmatch_flags |= FNM_CASEFOLD;
 }
 
 
 static void
 filter_destroy (Filter *filter)
 {
-        g_return_if_fail (filter != NULL);
+	g_return_if_fail (filter != NULL);
 
 	g_free (filter->pattern);
 	if (filter->patterns != NULL)
 		g_strfreev (filter->patterns);
-        g_free (filter);
+	g_free (filter);
 }
 
 
@@ -99,8 +99,8 @@ filter_apply (Filter     *filter,
 	char       *utf8_name;
 	gboolean    retval;
 
-        g_return_val_if_fail (filter != NULL, FALSE);
-        g_return_val_if_fail (name != NULL, FALSE);
+	g_return_val_if_fail (filter != NULL, FALSE);
+	g_return_val_if_fail (name != NULL, FALSE);
 
 	file_name = file_name_from_path (name);
 
@@ -116,7 +116,7 @@ filter_apply (Filter     *filter,
 	retval = match_patterns (filter->patterns, utf8_name, filter->fnmatch_flags);
 	g_free (utf8_name);
 
-        return retval;
+	return retval;
 }
 
 
@@ -168,7 +168,7 @@ wc_search_data_free (WCSearchData *data)
 		g_free (data->start_from);
 		data->start_from = NULL;
 	}
-	
+
 	if (data->uri != NULL)
 		gnome_vfs_uri_unref (data->uri);
 
@@ -181,13 +181,13 @@ wc_add_file (GnomeVFSFileInfo *info,
 	     WCSearchData     *data)
 {
 	if ((info->type != GNOME_VFS_FILE_TYPE_DIRECTORY)
-	    && filter_apply_from_info (data->filter, info)) 
-		data->files = g_list_prepend (data->files, 
+	    && filter_apply_from_info (data->filter, info))
+		data->files = g_list_prepend (data->files,
 					      g_strdup (info->name));
 }
 
 
-static gboolean 
+static gboolean
 wc_visit_cb (const gchar      *rel_path,
 	     GnomeVFSFileInfo *info,
 	     gboolean          recursing_will_loop,
@@ -198,7 +198,7 @@ wc_visit_cb (const gchar      *rel_path,
 
 	if ((info->type != GNOME_VFS_FILE_TYPE_DIRECTORY)
 	    && filter_apply (data->filter, rel_path)) {
-		data->files = g_list_prepend (data->files, 
+		data->files = g_list_prepend (data->files,
 					      g_strdup (rel_path));
 	}
 
@@ -214,24 +214,24 @@ pattern_present (char       **patterns,
 {
 	gboolean found = FALSE;
 	int      i;
-       
+
 	if ((patterns == NULL) || (patterns[0] == NULL))
 		return FALSE;
-	
+
 	if (pattern == NULL)
 		return FALSE;
-	
-	for (i = 0; (patterns[i] != NULL) && !found; i++) 
-		if (g_utf8_collate (patterns[i], pattern) == 0) 
+
+	for (i = 0; (patterns[i] != NULL) && !found; i++)
+		if (g_utf8_collate (patterns[i], pattern) == 0)
 			found = TRUE;
-	
+
 	return found;
 }
 
 
 GList *
-get_wildcard_file_list (const char  *directory, 
-			const char  *filter_pattern, 
+get_wildcard_file_list (const char  *directory,
+			const char  *filter_pattern,
 			gboolean     recursive,
 			gboolean     follow_links,
 			gboolean     same_fs,
@@ -242,12 +242,12 @@ get_wildcard_file_list (const char  *directory,
 	WCSearchData                   *data;
 	GnomeVFSDirectoryFilterOptions  filter_options;
 	GnomeVFSResult                  result;
-	GnomeVFSFileInfoOptions         info_options; 
+	GnomeVFSFileInfoOptions         info_options;
 	GnomeVFSDirectoryVisitOptions   visit_options;
 	GList                          *list = NULL;
 
 	if ((directory == NULL) || (filter_pattern == NULL))
-                return NULL;
+		return NULL;
 
 	data = wc_search_data_new (directory);
 
@@ -284,11 +284,11 @@ get_wildcard_file_list (const char  *directory,
 		}
 	} else { 		/* recursive case */
 		/* visit options. */
-		
+
 		visit_options =  GNOME_VFS_DIRECTORY_VISIT_LOOPCHECK;
 		if (same_fs)
 			visit_options |= GNOME_VFS_DIRECTORY_VISIT_SAMEFS;
-		
+
 		result = gnome_vfs_directory_visit_uri (data->uri,
 							info_options,
 							visit_options,
@@ -361,7 +361,7 @@ dir_search_data_free (DirSearchData *data)
 		g_free (data->base_dir);
 		data->base_dir = NULL;
 	}
-	
+
 	if (data->uri != NULL)
 		gnome_vfs_uri_unref (data->uri);
 
@@ -369,7 +369,7 @@ dir_search_data_free (DirSearchData *data)
 }
 
 
-static gboolean 
+static gboolean
 dir_visit_cb (const gchar      *rel_path,
 	      GnomeVFSFileInfo *info,
 	      gboolean          recursing_will_loop,
@@ -399,7 +399,7 @@ get_directory_file_list (const char *directory,
 {
 	DirSearchData *                data;
 	GnomeVFSResult                 result;
-	GnomeVFSFileInfoOptions        info_options; 
+	GnomeVFSFileInfoOptions        info_options;
 	GnomeVFSDirectoryVisitOptions  visit_options;
 	GList *                        list = NULL;
 
@@ -407,7 +407,7 @@ get_directory_file_list (const char *directory,
 
 	/* file filter */
 
-	data->filter = filter_new ("*", 
+	data->filter = filter_new ("*",
 				   (GNOME_VFS_DIRECTORY_FILTER_NOBACKUPFILES
 				    | GNOME_VFS_DIRECTORY_FILTER_NODOTFILES));
 
@@ -435,9 +435,9 @@ get_directory_file_list (const char *directory,
 
 
 typedef struct _PathListData PathListData;
-
 typedef void (*PathListDoneFunc) (PathListData *dld, gpointer data);
 
+
 struct _PathListData {
 	GnomeVFSURI      *uri;
 	GnomeVFSResult    result;
@@ -450,28 +450,26 @@ struct _PathListData {
 	gboolean          interrupted;
 };
 
+
 typedef struct {
 	GnomeVFSAsyncHandle *vfs_handle;
 	PathListData *pli_data;
 } PathListHandle;
 
+
 PathListData *      path_list_data_new           ();
-
 void                path_list_data_free          (PathListData     *dli);
-
 void                path_list_handle_free        (PathListHandle   *handle);
-
 PathListHandle *    path_list_async_new          (const char       *uri,
 						  gboolean          follow_links,
 						  PathListDoneFunc  f,
 						  gpointer          data);
-
 void                path_list_async_interrupt    (PathListHandle   *handle,
 						  DoneFunc          f,
 						  gpointer          data);
 
 
-PathListData * 
+PathListData *
 path_list_data_new ()
 {
 	PathListData *pli;
@@ -492,7 +490,7 @@ path_list_data_new ()
 }
 
 
-void 
+void
 path_list_data_free (PathListData *pli)
 {
 	g_return_if_fail (pli != NULL);
@@ -537,7 +535,7 @@ directory_load_cb (GnomeVFSAsyncHandle *handle,
 	pli->result = result;
 
 	if (pli->interrupted) {
-		if (pli->interrupt_func) 
+		if (pli->interrupt_func)
 			pli->interrupt_func (pli->interrupt_data);
 		path_list_data_free (pli);
 		return;
@@ -547,28 +545,20 @@ directory_load_cb (GnomeVFSAsyncHandle *handle,
 		GnomeVFSFileInfo *info     = node->data;
 		GnomeVFSURI      *full_uri = NULL;
 		char             *str_uri;
-		char             *unesc_uri;
 
 		switch (info->type) {
 		case GNOME_VFS_FILE_TYPE_REGULAR:
 			full_uri = gnome_vfs_uri_append_file_name (pli->uri, info->name);
-			str_uri = gnome_vfs_uri_to_string (full_uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
-			unesc_uri = gnome_vfs_unescape_string (str_uri, NULL);
-
-			pli->files = g_list_prepend (pli->files, unesc_uri);
-			g_free (str_uri);
+			str_uri = gnome_vfs_uri_to_string (full_uri, GNOME_VFS_URI_HIDE_NONE);
+			pli->files = g_list_prepend (pli->files, str_uri);
 			break;
 
 		case GNOME_VFS_FILE_TYPE_DIRECTORY:
 			if (SPECIAL_DIR (info->name))
 				break;
-
 			full_uri = gnome_vfs_uri_append_path (pli->uri, info->name);
-			str_uri = gnome_vfs_uri_to_string (full_uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
-			unesc_uri = gnome_vfs_unescape_string (str_uri, NULL);
-
-			pli->dirs = g_list_prepend (pli->dirs,  unesc_uri);
-			g_free (str_uri);
+			str_uri = gnome_vfs_uri_to_string (full_uri, GNOME_VFS_URI_HIDE_NONE);
+			pli->dirs = g_list_prepend (pli->dirs,  str_uri);
 			break;
 
 		default:
@@ -579,36 +569,30 @@ directory_load_cb (GnomeVFSAsyncHandle *handle,
 			gnome_vfs_uri_unref (full_uri);
 	}
 
-	if ((result == GNOME_VFS_ERROR_EOF) 
-	    || (result != GNOME_VFS_OK)) {
-		if (pli->done_func) 
+	if ((result == GNOME_VFS_ERROR_EOF) || (result != GNOME_VFS_OK)) {
+		if (pli->done_func)
 			/* pli must be deallocated in pli->done_func */
 			pli->done_func (pli, pli->done_data);
 		else
 			path_list_data_free (pli);
 
 		return;
-	} 
+	}
 }
 
 
 PathListHandle *
-path_list_async_new (const char       *uri, 
+path_list_async_new (const char       *uri,
 		     gboolean          follow_links,
 		     PathListDoneFunc  f,
 		     gpointer          data)
 {
 	GnomeVFSAsyncHandle *handle = NULL;
 	PathListData        *pli;
-	char                *escaped;
 	PathListHandle      *pl_handle;
 
 	pli = path_list_data_new ();
-
-	escaped = gnome_vfs_escape_path_string (uri);
-	pli->uri = gnome_vfs_uri_new (escaped);
-	g_free (escaped);
-
+	pli->uri = gnome_vfs_uri_new (uri);
 	pli->done_func = f;
 	pli->done_data = data;
 
@@ -662,7 +646,7 @@ struct _VisitDirData {
 	GList            *files;
 
 	/* private */
-	
+
 	Filter           *filter;
 	GHashTable       *dirnames;
 };
@@ -686,7 +670,7 @@ visit_dir_data_free (VisitDirData *vdd)
 		path_list_free (vdd->dirs);
 	if (vdd->files != NULL)
 		path_list_free (vdd->files);
-	
+
 	if (vdd->filter)
 		filter_destroy (vdd->filter);
 
@@ -704,72 +688,66 @@ static gboolean
 same_fs (const char *path1,
 	 const char *path2)
 {
-	char           *escaped;
 	GnomeVFSURI    *uri1, *uri2;
 	GnomeVFSResult  result;
 	gboolean        same;
 
-	escaped = gnome_vfs_escape_path_string (path1);
-	uri1 = gnome_vfs_uri_new (escaped);
-	g_free (escaped);
-
-	escaped = gnome_vfs_escape_path_string (path2);
-	uri2 = gnome_vfs_uri_new (escaped);
-	g_free (escaped);
+	uri1 = gnome_vfs_uri_new (path1);
+	uri2 = gnome_vfs_uri_new (path2);
 
 	result = gnome_vfs_check_same_fs_uris (uri1, uri2, &same);
 
 	gnome_vfs_uri_unref (uri1);
-        gnome_vfs_uri_unref (uri2);
+	gnome_vfs_uri_unref (uri2);
 
 	return (result == GNOME_VFS_OK) && same;
 }
 
 
 static GList*
-get_dir_list_from_file_list (VisitDirData *vdd, 
+get_dir_list_from_file_list (VisitDirData *vdd,
 			     GList        *files,
 			     gboolean      is_dir_list)
 {
 	GList *scan;
 	GList *dir_list = NULL;
-	
+
 	for (scan = files; scan; scan = scan->next) {
 		char *filename = scan->data;
 		char *dir_name;
-		
+
 		if (is_dir_list)
 			dir_name = g_strdup (filename + strlen (vdd->base_dir) + 1);
 		else
 			dir_name = remove_level_from_path (filename + strlen (vdd->base_dir) + 1);
-		
+
 		while ((dir_name != NULL) && (dir_name[0] != '\0') && (strcmp (dir_name, "/") != 0)) {
 			char *tmp;
 			char *dir;
-			
+
 			/* avoid to insert duplicated folders */
 
 			dir = g_strconcat (vdd->base_dir, "/", dir_name, NULL);
-			if (g_hash_table_lookup (vdd->dirnames, dir) == NULL) { 
+			if (g_hash_table_lookup (vdd->dirnames, dir) == NULL) {
 				g_hash_table_insert (vdd->dirnames, dir, GINT_TO_POINTER (1));
 				dir_list = g_list_prepend (dir_list, dir);
 			} else
 				g_free (dir);
-			
+
 			tmp = dir_name;
 			dir_name = remove_level_from_path (tmp);
 			g_free (tmp);
 		}
-		
-		g_free (dir_name);	
+
+		g_free (dir_name);
 	}
-	
+
 	return dir_list;
 }
 
 
 static void
-vd_path_list_done_cb (PathListData *pld, 
+vd_path_list_done_cb (PathListData *pld,
 		      gpointer      data)
 {
 	VisitDirData *vdd = data;
@@ -777,7 +755,7 @@ vd_path_list_done_cb (PathListData *pld,
 	char         *sub_dir = NULL;
 
 	if (vdd->interrupted) {
-		if (vdd->interrupt_func) 
+		if (vdd->interrupt_func)
 			vdd->interrupt_func (vdd->interrupt_data);
 		visit_dir_data_free (vdd);
 
@@ -801,14 +779,14 @@ vd_path_list_done_cb (PathListData *pld,
 	if (vdd->filter != NULL)
 		for (scan = pld->files; scan; ) {
 			char *path = scan->data;
-			
+
 			if (! filter_apply (vdd->filter, path)) {
 				GList *next = scan->next;
-				
+
 				pld->files = g_list_remove_link (pld->files, scan);
 				g_list_free (scan);
 				g_free (path);
-				
+
 				scan = next;
 			} else
 				scan = scan->next;
@@ -818,9 +796,9 @@ vd_path_list_done_cb (PathListData *pld,
 		vdd->files = g_list_concat (get_dir_list_from_file_list (vdd, pld->files, FALSE), vdd->files);
 	vdd->files = g_list_concat (pld->files, vdd->files);
 	pld->files = NULL;
-	
+
 	if (vdd->include_directories)
-		if (strcmp (vdd->filter->pattern, "*") == 0) 
+		if (strcmp (vdd->filter->pattern, "*") == 0)
 			vdd->files = g_list_concat (get_dir_list_from_file_list (vdd, pld->dirs, TRUE), vdd->files);
 
 	if (! vdd->recursive) {
@@ -828,7 +806,7 @@ vd_path_list_done_cb (PathListData *pld,
 			(* vdd->done_func) (vdd->files, vdd->done_data);
 		path_list_data_free (pld);
 		visit_dir_data_free (vdd);
-		
+
 		return;
 	}
 
@@ -840,7 +818,7 @@ vd_path_list_done_cb (PathListData *pld,
 		if (vdd->done_func)
 			(* vdd->done_func) (vdd->files, vdd->done_data);
 		visit_dir_data_free (vdd);
-		
+
 		return;
 	}
 
@@ -872,9 +850,9 @@ _visit_dir_async (const char   *dir,
 		  VisitDirData *vdd)
 {
 	PathListHandle *handle;
-	handle = path_list_async_new (dir, 
-				      vdd->follow_links, 
-				      vd_path_list_done_cb, 
+	handle = path_list_async_new (dir,
+				      vdd->follow_links,
+				      vd_path_list_done_cb,
 				      vdd);
 	g_free (handle);
 }
@@ -882,8 +860,8 @@ _visit_dir_async (const char   *dir,
 
 VisitDirHandle *
 visit_dir_async (VisitDirHandle   *handle,
-		 const char       *directory, 
-		 const char       *filter_pattern, 
+		 const char       *directory,
+		 const char       *filter_pattern,
 		 gboolean          recursive,
 		 gboolean          follow_links,
 		 gboolean          same_fs,
@@ -899,7 +877,7 @@ visit_dir_async (VisitDirHandle   *handle,
 
 	vdd = g_new0 (VisitDirData, 1);
 	vdd->base_dir = g_strdup (directory);
-	vdd->directory = g_strdup (directory);
+	vdd->directory = get_uri_from_path (directory);
 	vdd->recursive = recursive;
 	vdd->include_directories = include_directories;
 	vdd->follow_links = follow_links;
@@ -915,19 +893,19 @@ visit_dir_async (VisitDirHandle   *handle,
 		filter_options |= GNOME_VFS_DIRECTORY_FILTER_NOBACKUPFILES;
 	if (no_dot_files)
 		filter_options |= GNOME_VFS_DIRECTORY_FILTER_NODOTFILES;
-	if (ignorecase) 
+	if (ignorecase)
 		filter_options |= GNOME_VFS_DIRECTORY_FILTER_IGNORECASE;
-	
+
 	if (filter_pattern != NULL)
 		vdd->filter = filter_new (filter_pattern, filter_options);
 
 	/* handle */
 
-	if (handle == NULL) 
+	if (handle == NULL)
 		handle = g_new0 (VisitDirHandle, 1);
 	handle->vdd_data = vdd;
 
-	_visit_dir_async (directory, vdd);
+	_visit_dir_async (vdd->directory, vdd);
 
 	return handle;
 }
@@ -989,7 +967,7 @@ get_file_list_data_free (GetFileListData *gfl_data)
 /* -- get_wildcard_file_list_async -- */
 
 
-static void 
+static void
 get_wildcard_file_list_cb (GList *files, gpointer data)
 {
 	GetFileListData *gfl_data = data;
@@ -1001,7 +979,7 @@ get_wildcard_file_list_cb (GList *files, gpointer data)
 
 		for (scan = files; scan; scan = scan->next) {
 			char *full_path = scan->data;
-			
+
 			if (path_in_path (gfl_data->directory, full_path)) {
 				char *rel_path = g_strdup (full_path + base_len + 1);
 				rel_files = g_list_prepend (rel_files, rel_path);
@@ -1009,10 +987,10 @@ get_wildcard_file_list_cb (GList *files, gpointer data)
 		}
 	}
 
-	if (gfl_data->done_func) 
+	if (gfl_data->done_func)
 		/* rel_files must be deallocated in pli->done_func */
 		gfl_data->done_func (rel_files, gfl_data->done_data);
-	else 
+	else
 		path_list_free (rel_files);
 
 	get_file_list_data_free (gfl_data);
@@ -1020,8 +998,8 @@ get_wildcard_file_list_cb (GList *files, gpointer data)
 
 
 VisitDirHandle *
-get_wildcard_file_list_async  (const char       *directory, 
-			       const char       *filter_pattern, 
+get_wildcard_file_list_async  (const char       *directory,
+			       const char       *filter_pattern,
 			       gboolean          recursive,
 			       gboolean          follow_links,
 			       gboolean          same_fs,
@@ -1036,13 +1014,13 @@ get_wildcard_file_list_async  (const char       *directory,
 
 	gfl_data = g_new0 (GetFileListData, 1);
 
-	gfl_data->directory = g_strdup (directory);
+	gfl_data->directory = get_uri_from_path (directory);
 	gfl_data->done_func = done_func;
 	gfl_data->done_data = done_data;
-	
+
 	return visit_dir_async (NULL,
 				directory,
-				filter_pattern, 
+				filter_pattern,
 				recursive,
 				follow_links,
 				same_fs,
@@ -1058,7 +1036,7 @@ get_wildcard_file_list_async  (const char       *directory,
 /* -- get_directory_file_list_async -- */
 
 
-static void 
+static void
 get_directory_file_list_cb (GList *files, gpointer data)
 {
 	GetFileListData *gfl_data = data;
@@ -1067,14 +1045,14 @@ get_directory_file_list_cb (GList *files, gpointer data)
 	if (gfl_data->base_dir != NULL) {
 		GList *scan;
 		int    base_len;
-		
+
 		base_len = 0;
 		if (strcmp (gfl_data->base_dir, "/") != 0)
 			base_len = strlen (gfl_data->base_dir);
 
 		for (scan = files; scan; scan = scan->next) {
 			char *full_path = scan->data;
-			
+
 			if (strncmp (gfl_data->base_dir, full_path, base_len) == 0) {
 				char *rel_path = g_strdup (full_path + base_len + 1);
 				rel_files = g_list_prepend (rel_files, rel_path);
@@ -1082,10 +1060,10 @@ get_directory_file_list_cb (GList *files, gpointer data)
 		}
 	}
 
-	if (gfl_data->done_func) 
+	if (gfl_data->done_func)
 		/* rel_files must be deallocated in pli->done_func */
 		gfl_data->done_func (rel_files, gfl_data->done_data);
-	else 
+	else
 		path_list_free (rel_files);
 
 	get_file_list_data_free (gfl_data);
@@ -1112,7 +1090,7 @@ get_directory_file_list_async (const char       *directory,
 	gfl_data->done_data = done_data;
 
 	if (strcmp (base_dir, "/") == 0)
-        	path = g_strconcat (base_dir, directory, NULL);
+		path = g_strconcat (base_dir, directory, NULL);
 	else
 		path = g_strconcat (base_dir, "/", directory, NULL);
 
@@ -1154,7 +1132,7 @@ visit_current_dir_idle_cb (gpointer data)
 }
 
 
-static void 
+static void
 get_items_file_list_cb (GList *files, gpointer data)
 {
 	GetFileListData *gfl_data = data;
@@ -1162,7 +1140,7 @@ get_items_file_list_cb (GList *files, gpointer data)
 	if (gfl_data->base_dir != NULL) {
 		GList *scan;
 		int    base_len;
-		
+
 		base_len = 0;
 		if (strcmp (gfl_data->base_dir, "/") != 0)
 			base_len = strlen (gfl_data->base_dir);
@@ -1189,10 +1167,10 @@ visit_current_dir (GetFileListData *gfl_data)
 	char       *path;
 
 	if (gfl_data->current_dir == NULL) {
-		if (gfl_data->done_func) 
+		if (gfl_data->done_func)
 			/* gfl_data->files must be deallocated in gfl_data->done_func */
 			gfl_data->done_func (gfl_data->files, gfl_data->done_data);
-		else 
+		else
 			path_list_free (gfl_data->files);
 		get_file_list_data_free (gfl_data);
 		return NULL;
@@ -1200,7 +1178,7 @@ visit_current_dir (GetFileListData *gfl_data)
 
 	directory = file_name_from_path ((char*) gfl_data->current_dir->data);
 	if (strcmp (gfl_data->base_dir, "/") == 0)
-        	path = g_strconcat (gfl_data->base_dir, directory, NULL);
+		path = g_strconcat (gfl_data->base_dir, directory, NULL);
 	else
 		path = g_strconcat (gfl_data->base_dir, "/", directory, NULL);
 
@@ -1210,7 +1188,7 @@ visit_current_dir (GetFileListData *gfl_data)
 			 TRUE,
 			 TRUE,
 			 TRUE,
-			 FALSE,
+			 TRUE,
 			 FALSE,
 			 FALSE,
 			 gfl_data->include_directories,
@@ -1236,18 +1214,19 @@ get_items_file_list_async (GList            *item_list,
 	g_return_val_if_fail (base_dir != NULL, NULL);
 
 	gfl_data = g_new0 (GetFileListData, 1);
-	
+
 	base_len = 0;
 	if (strcmp (base_dir, "/") != 0)
 		base_len = strlen (base_dir);
-	
+
 	for (scan = item_list; scan; scan = scan->next) {
 		char *path = scan->data;
 
 		if (path_is_file (path)) {
 			char *rel_path = g_strdup (path + base_len + 1);
 			gfl_data->files = g_list_prepend (gfl_data->files, rel_path);
-		} else if (path_is_dir (path))
+		}
+		else if (path_is_dir (path))
 			gfl_data->dir_list = g_list_prepend (gfl_data->dir_list, g_strdup (path));
 	}
 
