@@ -59,6 +59,8 @@ mktime_from_string (char *datetime_s)
 	char      *min;
 	char      *sec;
 
+	tm.tm_isdst = -1;
+
 	/* date */
 
 	date = datetime_s;
@@ -78,7 +80,7 @@ mktime_from_string (char *datetime_s)
 	hour = g_strndup (time, 2);
 	min = g_strndup (time + 2, 2);
 	sec = g_strndup (time + 4, 2);
-	tm.tm_hour = atoi (hour) - 1;
+	tm.tm_hour = atoi (hour);
 	tm.tm_min = atoi (min);
 	tm.tm_sec = atoi (sec);
 	g_free(hour);
@@ -202,7 +204,7 @@ list__process_line (char     *line,
 	if (*fdata->name == 0)
 		file_data_free (fdata);
 	else
-		comm->file_list = g_list_prepend (comm->file_list, fdata);
+		fr_command_add_file (comm, fdata);
 }
 
 
