@@ -62,7 +62,7 @@ typedef enum {
 	FR_BATCH_ACTION_EXTRACT_INTERACT,
 	FR_BATCH_ACTION_RENAME,
 	FR_BATCH_ACTION_PASTE,
-	FR_BATCH_ACTION_VIEW,
+	FR_BATCH_ACTION_OPEN_FILES,
 	FR_BATCH_ACTION_SAVE_AS,
 	FR_BATCH_ACTION_TEST,
 	FR_BATCH_ACTION_CLOSE,
@@ -183,13 +183,13 @@ const char*fr_window_get_current_location       (FrWindow       *window);
 void       fr_window_go_up_one_level            (FrWindow       *window);
 void       fr_window_go_back                    (FrWindow       *window);
 void       fr_window_go_forward                 (FrWindow       *window);
-void       fr_window_current_folder_activated   (FrWindow       *window);
+void       fr_window_current_folder_activated   (FrWindow       *window,
+						 gboolean        from_sidebar);
 void       fr_window_set_list_mode              (FrWindow       *window,
 						 FRWindowListMode  list_mode);
 
 /**/
 
-void       fr_window_update_file_list             (FrWindow    *window);
 void       fr_window_update_list_order            (FrWindow    *window);
 GList *    fr_window_get_file_list_selection      (FrWindow    *window,
 						   gboolean     recursive,
@@ -209,10 +209,14 @@ void       fr_window_set_sort_type                (FrWindow    *window,
 
 /**/
 
-void       fr_window_rename_selection             (FrWindow    *window);
-void       fr_window_cut_selection                (FrWindow    *window);
-void       fr_window_copy_selection               (FrWindow    *window);
-void       fr_window_paste_selection              (FrWindow    *window);
+void       fr_window_rename_selection             (FrWindow    *window,
+						   gboolean     from_sidebar);
+void       fr_window_cut_selection                (FrWindow    *window,
+						   gboolean     from_sidebar);
+void       fr_window_copy_selection               (FrWindow    *window,
+						   gboolean     from_sidebar);
+void       fr_window_paste_selection              (FrWindow    *window,
+						   gboolean     from_sidebar);
 
 /**/
 
@@ -224,16 +228,16 @@ void       fr_window_stop_activity_mode           (FrWindow    *window);
 
 void        fr_window_view_last_output            (FrWindow   *window,
 						   const char *title);
-void        fr_window_view_file                   (FrWindow   *window,
-						   char       *file);
+
 void        fr_window_open_files                  (FrWindow   *window,
+						   GList      *file_list,
+						   gboolean    ask_application);
+void        fr_window_open_files_with_command     (FrWindow   *window,
 						   GList      *file_list,
 						   char       *command);
 void        fr_window_open_files_with_application (FrWindow   *window,
 						   GList      *file_list,
 						   GnomeVFSMimeApplication *app);
-void        fr_window_view_or_open_file           (FrWindow   *window,
-						   char       *file);
 void        fr_window_update_columns_visibility   (FrWindow   *window);
 void        fr_window_update_history_list         (FrWindow   *window);
 void        fr_window_set_default_dir             (FrWindow   *window,
