@@ -66,18 +66,49 @@ static GtkActionEntry action_entries[] = {
 	  N_("Contents"), "F1",
 	  N_("Display the File Roller Manual"),
 	  G_CALLBACK (activate_action_manual) },
+	  
 	{ "Copy", GTK_STOCK_COPY,
 	  NULL, NULL,
 	  N_("Copy the selection"),
 	  G_CALLBACK (activate_action_copy) },
 	{ "Cut", GTK_STOCK_CUT,
 	  NULL, NULL,
-	  N_("Cut the selection"),
+	  N_("Cut the selection"),	  
 	  G_CALLBACK (activate_action_cut) },
+	{ "Paste", GTK_STOCK_PASTE,
+	  NULL, NULL,
+	  N_("Paste the clipboard"),
+	  G_CALLBACK (activate_action_paste) },	 
+	{ "Rename", NULL,
+	  N_("_Rename..."), "F2",
+	  N_("Rename the selection"),
+	  G_CALLBACK (activate_action_rename) },	   
 	{ "Delete", GTK_STOCK_DELETE,
 	  NULL, NULL,
 	  N_("Delete the selection from the archive"),
 	  G_CALLBACK (activate_action_delete) },
+	  
+	{ "CopyFolderFromSidebar", GTK_STOCK_COPY,
+	  NULL, NULL,
+	  N_("Copy the selection"),
+	  G_CALLBACK (activate_action_copy_folder_from_sidebar) },
+	{ "CutFolderFromSidebar", GTK_STOCK_CUT,
+	  NULL, NULL,
+	  N_("Cut the selection"),
+	  G_CALLBACK (activate_action_cut_folder_from_sidebar) },
+	{ "PasteFolderFromSidebar", GTK_STOCK_PASTE,
+	  NULL, NULL,
+	  N_("Paste the clipboard"),
+	  G_CALLBACK (activate_action_paste_folder_from_sidebar) },	 	
+	{ "RenameFolderFromSidebar", NULL,
+	  N_("_Rename..."), "F2",
+	  N_("Rename the selection"),
+	  G_CALLBACK (activate_action_rename_folder_from_sidebar) },	    
+	{ "DeleteFolderFromSidebar", GTK_STOCK_DELETE,
+	  NULL, NULL,
+	  N_("Delete the selection from the archive"),
+	  G_CALLBACK (activate_action_delete_folder_from_sidebar) },
+	  
 	{ "DeselectAll", NULL,
 	  N_("Dese_lect All"), NULL,
 	  N_("Deselect all files"),
@@ -86,6 +117,10 @@ static GtkActionEntry action_entries[] = {
 	  N_("_Extract..."), NULL,
 	  N_("Extract files from the archive"),
 	  G_CALLBACK (activate_action_extract) },
+	{ "ExtractFolderFromSidebar", FR_STOCK_EXTRACT,
+	  N_("_Extract..."), NULL,
+	  N_("Extract files from the archive"),
+	  G_CALLBACK (activate_action_extract_folder_from_sidebar) },
 	{ "Extract_Toolbar", FR_STOCK_EXTRACT,
 	  N_("Extract"), NULL,
 	  N_("Extract files from the archive"),
@@ -114,26 +149,14 @@ static GtkActionEntry action_entries[] = {
 	  N_("Pass_word..."), NULL,
 	  N_("Specify a password for this archive"),
 	  G_CALLBACK (activate_action_password) },
-	{ "Paste", GTK_STOCK_PASTE,
-	  NULL, NULL,
-	  N_("Paste the clipboard"),
-	  G_CALLBACK (activate_action_paste) },
 	{ "Properties", GTK_STOCK_PROPERTIES,
 	  NULL, NULL,
 	  N_("Show archive properties"),
 	  G_CALLBACK (activate_action_properties) },
-	{ "Quit", GTK_STOCK_QUIT,
-	  NULL, NULL,
-	  N_("Quit the application"),
-	  G_CALLBACK (activate_action_quit) },
 	{ "Reload", GTK_STOCK_REFRESH,
 	  NULL, "<control>R",
 	  N_("Reload current archive"),
 	  G_CALLBACK (activate_action_reload) },
-	{ "Rename", NULL,
-	  N_("_Rename..."), "F2",
-	  N_("Rename the selection"),
-	  G_CALLBACK (activate_action_rename) },
 	{ "SaveAs", GTK_STOCK_SAVE_AS,
 	  NULL, NULL,
 	  N_("Save the current archive with a different name"),
@@ -162,6 +185,10 @@ static GtkActionEntry action_entries[] = {
 	  NULL, NULL,
 	  N_("Open the selected folder"),
 	  G_CALLBACK (activate_action_open_folder) },
+	{ "OpenFolderFromSidebar", GTK_STOCK_OPEN,
+	  NULL, NULL,
+	  N_("Open the selected folder"),
+	  G_CALLBACK (activate_action_open_folder_from_sidebar) },
 };
 static guint n_action_entries = G_N_ELEMENTS (action_entries);
 
@@ -182,17 +209,22 @@ static GtkToggleActionEntry action_toggle_entries[] = {
 	  N_("Reverse the list order"),
 	  G_CALLBACK (activate_action_sort_reverse_order), 
 	  FALSE },
+	{ "ViewFolders", NULL,
+	  N_("_Folders"), "F9",
+	  N_("View the folders pane"),
+	  G_CALLBACK (activate_action_view_folders), 
+	  FALSE },
 };
 static guint n_action_toggle_entries = G_N_ELEMENTS (action_toggle_entries);
 
 
 static GtkRadioActionEntry view_as_entries[] = {
 	{ "ViewAllFiles", NULL,
-	  N_("View All _Files"), NULL,
-	  " ", WINDOW_LIST_MODE_FLAT },
+	  N_("View All _Files"), "<control>1",
+	  " ", FR_WINDOW_LIST_MODE_FLAT },
 	{ "ViewAsFolder", NULL,
-	  N_("View as a F_older"), NULL,
-	  " ", WINDOW_LIST_MODE_AS_DIR },
+	  N_("View as a F_older"), "<control>2",
+	  " ", FR_WINDOW_LIST_MODE_AS_DIR },
 };
 static guint n_view_as_entries = G_N_ELEMENTS (view_as_entries);
 
@@ -200,19 +232,19 @@ static guint n_view_as_entries = G_N_ELEMENTS (view_as_entries);
 static GtkRadioActionEntry sort_by_entries[] = {
 	{ "SortByName", NULL,
 	  N_("by _Name"), NULL,
-	  N_("Sort file list by name"), WINDOW_SORT_BY_NAME },
+	  N_("Sort file list by name"), FR_WINDOW_SORT_BY_NAME },
 	{ "SortBySize", NULL,
 	  N_("by _Size"), NULL,
-	  N_("Sort file list by file size"), WINDOW_SORT_BY_SIZE },
+	  N_("Sort file list by file size"), FR_WINDOW_SORT_BY_SIZE },
 	{ "SortByType", NULL,
 	  N_("by T_ype"), NULL,
-	  N_("Sort file list by type"), WINDOW_SORT_BY_TYPE },
+	  N_("Sort file list by type"), FR_WINDOW_SORT_BY_TYPE },
 	{ "SortByDate", NULL,
 	  N_("by _Date modified"), NULL,
-	  N_("Sort file list by modification time"), WINDOW_SORT_BY_TIME },
+	  N_("Sort file list by modification time"), FR_WINDOW_SORT_BY_TIME },
 	{ "SortByLocation", NULL,
 	  N_("by _Location"), NULL,
-	  N_("Sort file list by location"), WINDOW_SORT_BY_PATH },
+	  N_("Sort file list by location"), FR_WINDOW_SORT_BY_PATH },
 };
 static guint n_sort_by_entries = G_N_ELEMENTS (sort_by_entries);
 
@@ -234,7 +266,6 @@ static const gchar *ui_info =
 "      <menuitem action='Properties'/>"
 "      <separator/>"
 "      <menuitem action='Close'/>"
-"      <menuitem action='Quit'/>"
 "    </menu>"
 "    <menu action='EditMenu'>"
 "      <menuitem action='AddFiles'/>"
@@ -252,14 +283,12 @@ static const gchar *ui_info =
 "      <menuitem action='Password'/>"
 "    </menu>"
 "    <menu action='ViewMenu'>"
-"      <menuitem action='ViewToolbar'/>"
-"      <menuitem action='ViewStatusbar'/>"
-"      <separator/>"
 "      <menuitem action='Stop'/>"
 "      <menuitem action='Reload'/>"
 "      <separator/>"
-"      <menuitem action='ViewAllFiles'/>"
-"      <menuitem action='ViewAsFolder'/>"
+"      <menuitem action='ViewToolbar'/>"
+"      <menuitem action='ViewStatusbar'/>"
+"      <menuitem action='ViewFolders'/>"
 "      <separator/>"
 "      <menu action='ArrangeFilesMenu'>"
 "        <menuitem action='SortByName'/>"
@@ -271,6 +300,9 @@ static const gchar *ui_info =
 "        <menuitem action='SortReverseOrder'/>"
 "      </menu>"
 "      <separator/>"
+"      <menuitem action='ViewAllFiles'/>"
+"      <menuitem action='ViewAsFolder'/>" 
+"      <separator/>"
 "      <menuitem action='LastOutput'/>"
 "    </menu>"
 "    <menu action='HelpMenu'>"
@@ -315,7 +347,17 @@ static const gchar *ui_info =
 "    <menuitem action='AddFiles'/>"
 "    <menuitem action='AddFolder'/>"
 "  </popup>"
-
+"  <popup name='SidebarFolderPopupMenu'>"
+"    <menuitem action='OpenFolderFromSidebar'/>"
+"    <separator/>"
+"    <menuitem action='ExtractFolderFromSidebar'/>"
+"    <separator/>"
+"    <menuitem action='CutFolderFromSidebar'/>"
+"    <menuitem action='CopyFolderFromSidebar'/>"
+"    <menuitem action='PasteFolderFromSidebar'/>"
+"    <menuitem action='RenameFolderFromSidebar'/>"
+"    <menuitem action='DeleteFolderFromSidebar'/>"
+"  </popup>"
 "</ui>";
 
 
